@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "easky" "0.2.0"
+(define-package "easky" "20251231.1607"
   "Control the Eask command-line interface."
   '((emacs          "27.1")
     (eask-mode      "0.1.0")
@@ -8,8 +8,8 @@
     (lv             "0.0")
     (marquee-header "0.1.0"))
   :url "https://github.com/emacs-eask/easky"
-  :commit "f68ef0376b16aa3cebe651a8782cf9076ea0f7dd"
-  :revdesc "f68ef0376b16"
+  :commit "efe25f0c1ba483378854795fcfe7fa0367cebf27"
+  :revdesc "efe25f0c1ba4"
   :keywords '("maint" "easky")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
